"""
Tic Tac Toe Game
~~~~~~~~~~~~~~~~

A basic package to facilitate
games of tic-tac-toe

:copyright: (c) 2021-present Robert Offord
:license: MIT, see LICENSE for more details.

"""
__title__ = "tictacpy"
__author__ = "Robert Offord"
__license__ = 'MIT'
__copyright__ = 'Copyright 2021-present Robert Offord'
__version__ = '1.0.0'

from .game import TTT
from .errors import *
from .board import Board


from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Developers',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]

readme = ''
with open('README.md') as f:
    readme = f.read()
 
setup(
  name='tictacpy',
  version='1.0.0',
  description='Play tic tac toe with friends',
  long_description=readme,
  url='https://github.com/ImpassiveMoon03/tictacpy',  
  author='Robert Offord',
  author_email='impassivedeveloper@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='Tictactoe', 
  packages=find_packages(),
  install_requires=[''] 
)